// --8<--8<--8<--8<--
//
// Copyright (C) 2006 Smithsonian Astrophysical Observatory
//
// This file is part of suplibxx
//
// suplibxx is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// suplibxx is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the 
//       Free Software Foundation, Inc. 
//       51 Franklin Street, Fifth Floor
//       Boston, MA  02110-1301, USA
//
// -->8-->8-->8-->8--

#include <string>

#define CATCH_CONFIG_MAIN
#include <catch2/catch.hpp>


#include "colselect.h"

TEST_CASE( "match", "[match]" ) {

  string str( "A_eff1.2" );

  string pat1( "^[A-Z].+\\d$" ), pat2( "\\-" );

  UNSCOPED_INFO( str + " =~ " + pat1 );
  REQUIRE( suplib::match( str, pat1 ) == true );

  UNSCOPED_INFO( str + " !~ " + pat2 );
  REQUIRE( suplib::match( str, pat2 ) == false );

}


TEST_CASE( "colselect", "[colselect]" ) {

  vector<string> input = { "col0", "Col1", "COl2", "COL3", "COL$", "5loc" };
  vector<string> exact_add = { "5loc", "foo", "Col1" };
  
  vector<string> regex_add = { "ol", "\\$" };

  vector<string> exact_del = { "5loc", "foo" , "Col1" };

  vector<string> regex_del = { "\\$" };

  vector<string> expected = { "col0" };

  vector<string> got;

  suplib::colselect( input, exact_add, regex_add, exact_del, regex_del, got );

  REQUIRE( got == expected  );

}

